@@ -545,10 +545,10 @@ def pg_stage(self, stagingqueue_pk):
         cursor = cnxn.cursor()
         
         # set aside info about the related ImportQueue object
+        state = stg_input.state
+        year = stg_input.year
         load = stg_input.imported_via
         meta = load.get_meta()
-        state = load.file.state.abbreviation
-        year = load.file.year
         
         # generate the destination table name
         output_tbl = '_'.join(str(x) for x in ['stg', state, year, category, now_hr]).lower()
@@ -678,6 +678,7 @@ def pg_stage(self, stagingqueue_pk):
             else:
                 pr_tbl = stg_q.pr_input.name
             
+            
             # create a table using "static" long PR definition
             create_sql = pyhcup.db.long_table_sql(output_tbl, 'UFLAGS')
             cursor.execute(create_sql)
@@ -694,7 +695,7 @@ def pg_stage(self, stagingqueue_pk):
             for uf in flaggers:
                 # take advantage of in-database processing for these
                 stg_q.log('%s: processing' % uf.name)
-                uflag_sql = uf.sql(output_tbl, input_tbl, pr_tbl, charges_tbl)
+                uflag_sql = uf.sql(output_tbl, input_tbl, pr_tbl, charges_tbl, state=state, year=year)
                 cursor.execute(uflag_sql)
                 uflag_count = cursor.rowcount
                 affected_rows += uflag_count
@@ -895,8 +896,17 @@ def pg_stage(self, stagingqueue_pk):
         stg_q.success('StagingTable {tbl} (pk {tbl_pk}) saved as stg_output for StagingQueue object {stg}' \
             .format(tbl=staged.name, tbl_pk=staged.pk, stg=stg_q.pk))
 
-        stg_q.success('Seeking deprecated StagingTable objects to mark as void (looking for category {cat}, state {st}, year {yr}, with pk NOT {pk}' \
+        logger.info('Seeking deprecated StagingTable objects to mark as void (looking for category {cat}, state {st}, year {yr}, with pk NOT {pk})' \
             .format(cat=staged.category, st=staged.state, yr=staged.year, pk=staged.pk))
+        deprecate_qs = StagingTable.objects \
+            .filter(category=staged.category, wip=False, void=False) \
+            .exclude(pk=staged.pk)
+        deprecate_lst = filter(lambda x: x.state==staged.state and x.year==staged.year, deprecate_qs)
+        for d in deprecate_lst:
+            logger.info('Deprecating StagingTable object {stg_pk} ({stg_name})' \
+                .format(stg_pk=d.pk, stg_name=d.name))
+            d.void = True
+            d.save()
         
         return True
 
