@@ -118,7 +118,8 @@ def unprocessed_batches(conversions=STAGING_CONVERSIONS,
                                 x.year==yr and
                                 x.data_source.parent is not None and
                                 x.data_source.parent.abbreviation == ds,
-                                reqd_qs)
+                                reqd_qs
+                            )
                             
                             if len(reqd_lst) > 0:
                                 #print "reqd found some matching {attr}".format(attr=attr)
@@ -164,7 +165,6 @@ def unprocessed_batches(conversions=STAGING_CONVERSIONS,
                                     .filter(category=opt, wip=False) \
                                     .order_by('-created_at')
                                 
-                                
                                 opt_lst = filter(
                                     lambda x: x.state==st and
                                     x.year==yr and
@@ -183,7 +183,6 @@ def unprocessed_batches(conversions=STAGING_CONVERSIONS,
                                         # unable to add a second time if already not None
                                         # should emit a logger error about this
                                         opts.append(False)
-                                
                                 else:
                                     opts.append(False)
                         
@@ -203,10 +202,19 @@ def unprocessed_batches(conversions=STAGING_CONVERSIONS,
                                 .filter(category=cat_out, complete__isnull=False,
                                         stg_output__isnull=False, void=False)
                             
+                            # NB reqs and opts are already based on what is available to build a
+                            # StagingTable at this time. Therefore, they can be safely joined with
+                            # operator.and_ rather than operator.or_ (ie "is there anything out
+                            # there that matches ALL of the available required and available
+                            # optional inputs?")
+                            # TODO: totally should move this shit to some kind of function or
+                            # StagingTable method. It's gross to have it out here and not at all
+                            # DRY when something similar is needed to deprecate tables down the
+                            # line.
                             reqd_predicates = [('%s__isnull' % CAT_IN_TO_ATTR[x], False) for x in reqs if x is not False]
                             opt_predicates = [('%s__isnull' % CAT_IN_TO_ATTR[x], False) for x in opts if x is not False]
                             equiv_q_lst = [Q(x) for x in reqd_predicates + opt_predicates]
-                            equivalent_qs = st_tbl_qs.filter(reduce(operator.or_, equiv_q_lst))
+                            equivalent_qs = st_tbl_qs.filter(reduce(operator.and_, equiv_q_lst))
                             
                             equivalent_lst = filter(lambda x: x.stg_input.state==st and x.stg_input.year==yr, equivalent_qs)
                             equivalent_ct = len(equivalent_lst)
@@ -220,7 +228,7 @@ def unprocessed_batches(conversions=STAGING_CONVERSIONS,
                             reqd_predicates = [('%s__isnull' % CAT_IN_TO_ATTR[x], False) for x in reqs if x is not False]
                             opt_predicates = [('%s__isnull' % CAT_IN_TO_ATTR[x], False) for x in opts if x is not False]
                             inb_q_lst = [Q(x) for x in reqd_predicates + opt_predicates]
-                            inb_qs = inb_st_tbl_qs.filter(reduce(operator.or_, inb_q_lst))
+                            inb_qs = inb_st_tbl_qs.filter(reduce(operator.and_, inb_q_lst))
                             
                             inb_lst = filter(lambda x: x.stg_input.state==st and x.stg_input.year==yr, inb_qs)
                             inb_ct = len(inb_lst)
@@ -230,7 +238,7 @@ def unprocessed_batches(conversions=STAGING_CONVERSIONS,
                                 b.log(msg.format(state=st, year=yr, category=cat_out))
                                 stg_q.batch = b
                                 stg_q.save()
-                                b.log("Saved StagingQueue {pk} for {state} {year} {category}."\
+                                b.log("Saved StagingQueue {pk} for {state} {year} {category}." \
                                     .format(pk=stg_q.pk, state=st, year=yr, category=cat_out))
                             
                             elif inb_ct > 0:
@@ -240,6 +248,12 @@ def unprocessed_batches(conversions=STAGING_CONVERSIONS,
                             elif equivalent_ct > 0:
                                 msg = "There are already one or more StagingTable objects for {state} {year} {category} with the constellation of inputs now available."
                                 b.log(msg.format(state=st, year=yr, category=cat_out))
+                                #print reqs
+                                #print opts
+                                #print equiv_q_lst
+                                #print equivalent_qs
+                                #print equivalent_qs.query
+                                #print equivalent_lst
                                 # if replacing, delete old ones?
                                 # OR!
                                 # Set up a model to hold deprecation queues. Would have attributes like
@@ -247,6 +261,8 @@ def unprocessed_batches(conversions=STAGING_CONVERSIONS,
                                 # and a boolean for whether the old one has been dropped.
                                 # that could be pruned manually on a periodic basis, or whatevs.
                                 # would probably need to review dependencies/parent-child tbl relations
+                                # RESULT: This is done during the execution of the batch, not during
+                                # the contemplation and enqueuing phase.
                                 
         else:
             default_logger.info("Found no StagingTable objects with traceable heredity to parent data source with abbreviation {ds}. Therefore, the entire data source family was skipped.".format(ds=ds))
