@@ -156,10 +156,12 @@ def obj_detail(request, obj_id, obj_type, msg_pt=[]):
         }
         template = 'stg_detail_col.html'
     
+    context['messages'] = msg_pt
+    
     return render(request, template, context)
 
 
-def obj_inventory(request, obj_type, *args, **kwargs):    
+def obj_inventory(request, obj_type, msg_pt=[], *args, **kwargs):    
     logger.debug('Inventory requested for obj_type {t}.'\
         .format(t=obj_type))
     
@@ -288,6 +290,8 @@ def obj_inventory(request, obj_type, *args, **kwargs):
         
         template = 'stg_inv_tbl.html'
     
+    context['messages'] = msg_pt
+    
     return render(request, template, context)
 
 
@@ -319,9 +323,6 @@ def run_batch(request, obj_id, obj_type):
         return obj_detail(request, obj_id, obj_type, msg_pt=[response])
 
 
-
-
-
 def create_batch_from_unimported(request):
     b = staging.unimported_batch()
     
@@ -489,7 +490,7 @@ def file_discover(request):
     
     messages.append(dict(level="info", content=message))
     
-    return file_inventory(request, msg_pass_through=messages)
+    return obj_inventory(request, 'File', msg_pass_through=messages)
 
 
 def file_match(request):
@@ -534,5 +535,5 @@ def file_match(request):
     
     messages.append(dict(level="info", content=message))
     
-    return file_inventory(request, msg_pass_through=messages)
+    return obj_inventory(request, 'File', msg_pass_through=messages)
 
